## API Overview

This section is auto-generated from the Python docstrings using
`mkdocstrings`. It always reflects the latest installed version of
`quantumuq`.

### Core modules

::: quantumuq.core.methods

::: quantumuq.core.metrics

::: quantumuq.core.predictors

### Adapters

::: quantumuq.adapters.pennylane_adapter

::: quantumuq.adapters.qiskit_adapter

